pyelectro
=========

Tool for analysis of electrophysiology in Python.

**This package was originally developed by [Mike Vella](https://github.com/vellamike). This has been updated by [Padraig Gleeson](https://github.com/pgleeson) and others (and moved to [NeuralEnsemble](https://github.com/NeuralEnsemble)) to continue development of [pyelectro](https://github.com/NeuralEnsemble/pyelectro) and [Neurotune](https://github.com/NeuralEnsemble/neurotune) for use in [OpenWorm](http://www.openworm.org/), [Open Source Brain](http://opensourcebrain.org/) and other projects**

[![Build Status](https://travis-ci.org/NeuralEnsemble/pyelectro.svg?branch=master)](https://travis-ci.org/NeuralEnsemble/pyelectro)
